"""
Django settings for fluffy project.

Generated by 'django-admin startproject' using Django 4.0.1.

For more information on this file, see
https://docs.djangoproject.com/en/4.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/4.0/ref/settings/
"""
import os
from pathlib import Path

import ldap
from django.conf import settings
from django.conf.global_settings import SESSION_COOKIE_AGE, CSRF_COOKIE_AGE
from dotenv import load_dotenv

from fluffy.utils import getenv_bool, getenv_int

load_dotenv()

# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent


# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/4.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
DEVELOPMENT_SECRET = "django-insecure-^6^f66-#v%z_4nttug=tvs&&5!5ld2@v0p26=8sd971wo+4=e^"
SECRET_KEY = os.getenv('DJANGO_SECRET_KEY', default=DEVELOPMENT_SECRET)


# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = getenv_bool('DJANGO_DEBUG')

settings.DEBUG = DEBUG

# TODO: find out whether there is any favoured way in the Django mindset
HOSTNAME = os.getenv('HOSTNAME', default="localhost")
PORT = os.getenv('PUBLIC_PORT', default=8000)

ALLOWED_HOSTS = ["localhost", HOSTNAME]
CSRF_TRUSTED_ORIGINS = [
    "http://localhost:8000/",
    f"http://{HOSTNAME}:{PORT}/",
    f"https://{HOSTNAME}:{PORT}/",
    f"http://{HOSTNAME}:{PORT}",
    f"https://{HOSTNAME}:{PORT}",
    f"http://{HOSTNAME}",
    f"https://{HOSTNAME}"
]
CORS_ALLOWED_ORIGINS = [
    "http://localhost:8000",
    f"http://{HOSTNAME}:{PORT}",
    f"https://{HOSTNAME}:{PORT}"
]
CORS_ALLOW_CREDENTIALS = True
SESSION_COOKIE_SAMESITE = 'None'
SESSION_COOKIE_SECURE = True
CSRF_COOKIE_SAMESITE = 'None'
CSRF_COOKIE_SECURE = True

# Application definition

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
    "django_extensions",
    "corsheaders",
    "oauth2_authcodeflow",
    "rest_framework",
    "django_prometheus",
    "mqtt",
    "projects",
    "users",
]

MIDDLEWARE = [
    "django.middleware.csrf.CsrfViewMiddleware",
    "django_prometheus.middleware.PrometheusBeforeMiddleware",
    "corsheaders.middleware.CorsMiddleware",
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "oauth2_authcodeflow.middleware.BearerAuthMiddleware",

    "fluffy.middleware.SuperUserInterceptorMiddleware",
    "fluffy.middleware.HiveMqSyncMiddleware",

    "django_prometheus.middleware.PrometheusAfterMiddleware"
]

ROOT_URLCONF = "fluffy.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [
            BASE_DIR / 'frontend-build'
        ],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
        },
    },
]

WSGI_APPLICATION = "fluffy.wsgi.application"


# Database
# https://docs.djangoproject.com/en/4.0/ref/settings/#databases

DATABASES = {
    "default": {
        "ENGINE": "django_prometheus.db.backends.sqlite3",
        "NAME": BASE_DIR / "db/db.sqlite3",
    }
}

# Password validation
# https://docs.djangoproject.com/en/4.0/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.MinimumLengthValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.CommonPasswordValidator",
    },
    {
        "NAME": "django.contrib.auth.password_validation.NumericPasswordValidator",
    },
]

AUTH_USER_MODEL = "users.KitUser"


# Internationalization
# https://docs.djangoproject.com/en/4.0/topics/i18n/

LANGUAGE_CODE = "en-us"

TIME_ZONE = "UTC"

USE_I18N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/4.0/howto/static-files/

STATIC_URL = "/static/"

STATICFILES_DIRS = (
    BASE_DIR / "frontend-build" / "static",
    BASE_DIR / "frontend-build"
)

# Default primary key field type
# https://docs.djangoproject.com/en/4.0/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"

HIVE_MQ_DB = {
    "host": os.getenv("HIVEMQ_DB_HOST", default="localhost"),
    "port": getenv_int("HIVEMQ_DB_PORT", default=3306),
    "user": os.getenv("HIVEMQ_DB_USER", default="root"),
    "password": os.getenv("HIVEMQ_DB_PASSWORD", default="test123"),
    "database": os.getenv("HIVEMQ_DB_NAME", default=""),
    "no_sync": getenv_bool('HIVEMQ_NO_SYNC')
}

MQTT = {
    "HASH_ROUNDS": 10,
    "HASH_ALGORITHM": "SHA512",
    "HIVE_MQ_DB": HIVE_MQ_DB
}

REST_FRAMEWORK = {
    "DEFAULT_PERMISSION_CLASSES": [
        "rest_framework.permissions.IsAuthenticated",
    ],
    "DEFAULT_AUTHENTICATION_CLASSES": [
        # "rest_framework.authentication.BasicAuthentication",
        "rest_framework.authentication.SessionAuthentication"
    ]
}

AUTHENTICATION_BACKENDS = [
    "oauth2_authcodeflow.auth.AuthenticationBackend",
    "django.contrib.auth.backends.ModelBackend",
]

# we use OIDC (OpenID Connect) for authentication of the current user itself
OIDC_OP_DISCOVERY_DOCUMENT_URL = (
    "https://oidc.scc.kit.edu/auth/realms/kit/.well-known/openid-configuration"
)
OIDC_RP_CLIENT_ID = str(os.getenv("OIDC_CLIENT_ID"))
# there is no secret because we are using Browser-Based Auth Code Flow
# cf. https://www.oauth.com/oauth2-servers/single-page-apps/#authorization
OIDC_RP_CLIENT_SECRET = ""
OIDC_RP_SCOPES = ["openid", "email", "profile"]
OIDC_EXTEND_USER = "users.auth_management.extend_user"
OIDC_DJANGO_USERNAME_FUNC = "users.auth_management.username_func"
OIDC_MIDDLEWARE_SESSION_TIMEOUT_SECONDS = 86400  # 1 day
OIDC_MIDDLEWARE_NO_AUTH_URL_PATTERNS = ["^/is-responding"]

# we also use a custom LDAP connection in order to retrieve the directory of available users
LDAP_HOST_URL = os.getenv("LDAP_HOST_URL", default="ldaps://kit-ad.scc.kit.edu")
LDAP_BIND_DN = os.getenv("LDAP_BIND_DN", default="KIT\ldap_read")
LDAP_BIND_PW = os.getenv("LDAP_BIND_PW", default="")
# the ldap search base must be larger than ou=IAI alone, there are relevant members in other groups.
# this filter is the best we have, stated at 2023/08/25
DEFAULT_LDAP_SEARCH_BASE = "ou=Staff,ou=KIT,dc=kit,dc=edu"
DEFAULT_LDAP_SEARCH_FILTER = '''(&
    (sAMAccountName=*)
    (objectClass=organizationalPerson)
    (memberof:1.2.840.113556.1.4.1941:=CN=iai-alle,OU=Groups,OU=IAI,OU=Staff,OU=KIT,DC=kit,DC=edu)
)'''
LDAP_SEARCH_BASE = os.getenv("LDAP_SEARCH_BASE", default=DEFAULT_LDAP_SEARCH_BASE)
LDAP_SEARCH_FILTER = os.getenv("LDAP_SEARCH_FILTER", default=DEFAULT_LDAP_SEARCH_FILTER)

SUPERUSER_NAME = str(os.getenv("SUPERUSER_NAME"))

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'file': {
            'level': 'INFO',
            'class': 'logging.FileHandler',
            'filename': BASE_DIR / 'warning.log',
        },
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
        }
    },
    'loggers': {
        '': {
            'handlers': ['console', 'file'],
            'level': 'DEBUG',
            'propagate': True,
        },
    },
}

LOGIN_URL = '/login'

